package com.bonus.canteen.core.supply.mapper;

import java.util.List;
import com.bonus.canteen.core.supply.domain.SupplyWarehouseInfo;

/**
 * 仓库信息Mapper接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface SupplyWarehouseInfoMapper {
    /**
     * 查询仓库信息
     * 
     * @param warehouseId 仓库信息主键
     * @return 仓库信息
     */
    public SupplyWarehouseInfo selectSupplyWarehouseInfoByWarehouseId(Long warehouseId);

    public int getSupplyWarehouseCountByAreaIds(Long[] areaIds);

    /**
     * 查询仓库信息列表
     * 
     * @param supplyWarehouseInfo 仓库信息
     * @return 仓库信息集合
     */
    public List<SupplyWarehouseInfo> selectSupplyWarehouseInfoList(SupplyWarehouseInfo supplyWarehouseInfo);

    /**
     * 新增仓库信息
     * 
     * @param supplyWarehouseInfo 仓库信息
     * @return 结果
     */
    public int insertSupplyWarehouseInfo(SupplyWarehouseInfo supplyWarehouseInfo);

    /**
     * 修改仓库信息
     * 
     * @param supplyWarehouseInfo 仓库信息
     * @return 结果
     */
    public int updateSupplyWarehouseInfo(SupplyWarehouseInfo supplyWarehouseInfo);

    /**
     * 删除仓库信息
     * 
     * @param warehouseId 仓库信息主键
     * @return 结果
     */
    public int deleteSupplyWarehouseInfoByWarehouseId(Long warehouseId);

    /**
     * 批量删除仓库信息
     * 
     * @param warehouseIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSupplyWarehouseInfoByWarehouseIds(Long[] warehouseIds);
}
