package com.bonus.canteen.core.supply.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.supply.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.supply.domain.SupplyWarehouseInfo;
import com.bonus.canteen.core.supply.service.ISupplyWarehouseInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 仓库信息Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "仓库信息接口")
@RestController
@RequestMapping("/supply_warehouse_info")
public class SupplyWarehouseInfoController extends BaseController {
    @Autowired
    private ISupplyWarehouseInfoService supplyWarehouseInfoService;

    /**
     * 查询仓库信息列表
     */
    @ApiOperation(value = "查询仓库信息列表")
    //@RequiresPermissions("supply:info:list")
    @GetMapping("/list")
    public TableDataInfo list(SupplyWarehouseInfo supplyWarehouseInfo) {
        startPage();
        List<SupplyWarehouseInfo> list = supplyWarehouseInfoService.selectSupplyWarehouseInfoList(supplyWarehouseInfo);
        return getDataTable(list);
    }

    /**
     * 导出仓库信息列表
     */
    @ApiOperation(value = "导出仓库信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:info:export")
    @SysLog(title = "仓库信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出仓库信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SupplyWarehouseInfo supplyWarehouseInfo) {
        List<SupplyWarehouseInfo> list = supplyWarehouseInfoService.selectSupplyWarehouseInfoList(supplyWarehouseInfo);
        ExcelUtil<SupplyWarehouseInfo> util = new ExcelUtil<SupplyWarehouseInfo>(SupplyWarehouseInfo.class);
        util.exportExcel(response, list, "仓库信息数据");
    }

    /**
     * 获取仓库信息详细信息
     */
    @ApiOperation(value = "获取仓库信息详细信息")
    //@RequiresPermissions("supply:info:query")
    @GetMapping(value = "/{warehouseId}")
    public AjaxResult getInfo(@PathVariable("warehouseId") Long warehouseId) {
        return success(supplyWarehouseInfoService.selectSupplyWarehouseInfoByWarehouseId(warehouseId));
    }

    /**
     * 新增仓库信息
     */
    @ApiOperation(value = "新增仓库信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:info:add")
    @SysLog(title = "仓库信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增仓库信息")
    @PostMapping
    public AjaxResult add(@RequestBody SupplyWarehouseInfo supplyWarehouseInfo) {
        try {
            return toAjax(supplyWarehouseInfoService.insertSupplyWarehouseInfo(supplyWarehouseInfo));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改仓库信息
     */
    @ApiOperation(value = "修改仓库信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:info:edit")
    @SysLog(title = "仓库信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改仓库信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody SupplyWarehouseInfo supplyWarehouseInfo) {
        try {
            return toAjax(supplyWarehouseInfoService.updateSupplyWarehouseInfo(supplyWarehouseInfo));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除仓库信息
     */
    @ApiOperation(value = "删除仓库信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:info:remove")
    @SysLog(title = "仓库信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除仓库信息")
	@PostMapping("/del/{warehouseIds}")
    public AjaxResult remove(@PathVariable Long[] warehouseIds) {
        return toAjax(supplyWarehouseInfoService.deleteSupplyWarehouseInfoByWarehouseIds(warehouseIds));
    }
}
